#
# spec file for package jboss-logging
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global namedreltag .Final
%global namedversion %{version}%{?namedreltag}
Name:           jboss-logging
Version:        3.4.1
Release:        4.8
Summary:        The JBoss Logging Framework
License:        Apache-2.0
URL:            https://github.com/jboss-logging/jboss-logging
Source0:        https://github.com/jboss-logging/jboss-logging/archive/%{namedversion}/%{name}-%{namedversion}.tar.gz
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(log4j:log4j:1.2.16)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.logging.log4j:log4j-api)
BuildRequires:  mvn(org.jboss.logmanager:jboss-logmanager)
BuildRequires:  mvn(org.jboss:jboss-parent:pom:)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildArch:      noarch

%description
This package contains the JBoss Logging Framework.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -qn %{name}-%{namedversion}

%pom_xpath_set pom:properties/pom:version.org.apache.log4j 12

# SLF4j 1.7 upgrade
sed -i "s|map = MDC.getCopyOfContextMap();|map = (Map) MDC.getCopyOfContextMap();|" \
 src/main/java/org/jboss/logging/Slf4jLoggerProvider.java

# Unneeded task
%pom_remove_plugin :maven-source-plugin

cp -p src/main/resources/META-INF/LICENSE.txt .
sed -i 's/\r//' LICENSE.txt

%build
%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Fri Apr  8 2022 Fridrich Strba <fstrba@suse.com>
- Build against the provider of mvn(log4j:log4j:1.2.16) instead of
  mvn(log4j:log4j), in order to be able to build both on systems
  with and without reload4j (bsc#1197642)
* Tue Feb 22 2022 Fridrich Strba <fstrba@suse.com>
- Do not build against the log4j12 packages
* Wed Apr 15 2020 Stasiek Michalski <stasiek@michalski.cc>
- Fix the source url
* Mon Apr 13 2020 Stasiek Michalski <stasiek@michalski.cc>
- Update to 3.4.1
* Thu Nov 14 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of jboss-logging 3.3.0
